/**
 * Copyright (c) 2020-present, Goldman Sachs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { existsSync, mkdirSync, writeFileSync } from 'fs';
import { resolve } from 'path';

export const setup = (outputDir) => {
  if (!existsSync(outputDir)) {
    mkdirSync(outputDir);
  }

  writeFileSync(
    resolve(outputDir, 'version.json'),
    JSON.stringify(
      {
        buildTime: new Date().toISOString(),
        version: '0.0.0-local',
        commitSHA: 'local',
      },
      null,
      2,
    ),
  );

  writeFileSync(
    resolve(outputDir, 'config.json'),
    JSON.stringify(
      {
        appName: 'taxonomy',
        env: 'local',
        taxonomy: [
          {
            label: 'Enterprise',
            key: 'example',
            url: 'http://localhost:60001/api/taxonomy/taxonomy-tree',
            default: true,
          },
        ],
        engine: {
          url: 'http://localhost:6060/api',
        },
        depot: {
          url: 'http://localhost:9090/depot/api',
        },
        query: {
          url: 'http://localhost:8081/query',
        },
        studio: {
          url: 'http://localhost:8080/studio',
        },
      },
      undefined,
      2,
    ),
  );
};
